@@ -1,4 +1,6 @@
-import { AcmAlertInfo } from '@stolostron/ui-components'
+/* Copyright Contributors to the Open Cluster Management project */
+
+import { AcmAlertInfo } from '@open-cluster-management/ui-components'
 import {
     Card,
     CardBody,
@@ -8,7 +10,7 @@ import {
     PageSection,
     Title,
 } from '@patternfly/react-core'
-import React, { ReactNode } from 'react'
+import { ReactNode } from 'react'
 import { ResourceError, ResourceErrorCode } from '../lib/resource-request'
 
 export function getErrorInfo(error: unknown): AcmAlertInfo {
@@ -62,7 +64,7 @@ export function getErrorInfo(error: unknown): AcmAlertInfo {
                 title = 'Not implemented'
                 message = 'The resource access is not implemented.'
                 break
-            case ResourceErrorCode.RequestCancelled:
+            case ResourceErrorCode.RequestAborted:
                 title = 'Request cancelled'
                 message = 'The request was cancelled.'
                 break
