@@ -428,6 +428,11 @@ const ApplicationCreationPage = [
     },
 ]
 
+export const getControlDataAZR = (includeAutomation = true) => {
+    if (includeAutomation) return [...controlDataAZR, ...automationControlData]
+    return [...controlDataAZR]
+}
+
 const controlDataAZR = [
     ///////////////////////  connection  /////////////////////////////////////
     {
@@ -649,7 +654,6 @@ const controlDataAZR = [
         title: 'Networking',
     },
     ...networkingControlData,
-    ...automationControlData,
 ]
 
-export default controlDataAZR
+export default getControlDataAZR
