@@ -156,11 +156,21 @@ function isVisible(el, screenReader, recursed) {
   }
 
   // hidden from visual users
+  const elHeight = parseInt(style.getPropertyValue('height'));
+
+  // ways to hide content visually
+  const scrollableWithZeroHeight = getScroll(el) && elHeight === 0;
+  const posAbsoluteOverflowHiddenAndSmall =
+    style.getPropertyValue('position') === 'absolute' &&
+    elHeight < 2 &&
+    style.getPropertyValue('overflow') === 'hidden';
+
   if (
     !screenReader &&
     (isClipped(style) ||
       style.getPropertyValue('opacity') === '0' ||
-      (getScroll(el) && parseInt(style.getPropertyValue('height')) === 0))
+      scrollableWithZeroHeight ||
+      posAbsoluteOverflowHiddenAndSmall)
   ) {
     return false;
   }
